@@ -1,10 +1,11 @@
 r"""
-Module E3 indicator calculation
--------------------------------
+Module E3 - Indicator calculation
+==================================
 
 In module E3 the technical KPI are evaluated:
 - calculate renewable share
 - calculate degree of autonomy (DA)
+- calculate degree of net zero energy (NZE)
 - calculate total generation of each asset and total_internal_generation
 - calculate total feedin electricity equivalent
 - calculate energy flows between sectors
@@ -28,8 +29,7 @@ from multi_vector_simulator.utils.constants_json_strings import (
     CONNECTED_FEEDIN_SINK,
     CRF,
     LES_ENERGY_VECTOR_S,
-    EXCESS,
-    AUTO_SINK,
+    EXCESS_SINK,
     ENERGY_VECTOR,
     KPI,
     KPI_SCALARS_DICT,
@@ -54,6 +54,7 @@ from multi_vector_simulator.utils.constants_json_strings import (
     TOTAL_DEMAND,
     TOTAL_EXCESS,
     TOTAL_FEEDIN,
+    TOTAL_CONSUMPTION_FROM_PROVIDERS,
     SUFFIX_ELECTRICITY_EQUIVALENT,
     LCOeleq,
     ATTRIBUTED_COSTS,
@@ -61,6 +62,13 @@ from multi_vector_simulator.utils.constants_json_strings import (
     DEGREE_OF_AUTONOMY,
     ONSITE_ENERGY_FRACTION,
     ONSITE_ENERGY_MATCHING,
+    EMISSION_FACTOR,
+    TOTAL_EMISSIONS,
+    SPECIFIC_EMISSIONS_ELEQ,
+    UNIT,
+    UNIT_SPECIFIC_EMISSIONS,
+    UNIT_EMISSIONS,
+    DEGREE_OF_NZE,
 )
 
 
@@ -69,11 +77,13 @@ def all_totals(dict_values):
 
     Parameters
     ----------
+
     dict_values :
-        dict all input parameters and restults up to E0
+        dict all input parameters and results up to E0
 
     Returns
     -------
+
     type
         List of all total cost parameters for the project
 
@@ -161,10 +171,7 @@ def total_demand_and_excess_each_sector(dict_values):
                 total_demand_dict.update({energy_carrier: {}})
 
             # Evaluate excess
-            if (
-                consumption_asset
-                in dict_values[SIMULATION_SETTINGS][EXCESS + AUTO_SINK]
-            ):
+            if consumption_asset in dict_values[SIMULATION_SETTINGS][EXCESS_SINK]:
                 total_excess_dict.update(
                     {
                         energy_carrier: total_excess_dict[energy_carrier]
@@ -250,10 +257,7 @@ def calculate_electricity_equivalent_for_a_set_of_aggregated_values(
     logging.info(
         f"The {kpi_name+SUFFIX_ELECTRICITY_EQUIVALENT} of the LES is: {round(total_electricity_equivalent)} kWheleq."
     )
-    if kpi_name == TOTAL_EXCESS:
-        logging.warning(
-            f"The calculation of the {TOTAL_EXCESS} per sector and their energy equivalent may currently be faulty. Please refer to issue #559"
-        )
+
     return total_electricity_equivalent
 
 
@@ -283,6 +287,7 @@ def add_total_renewable_and_non_renewable_energy_origin(dict_values):
         renewable_origin.update({sector: 0})
         non_renewable_origin.update({sector: 0})
 
+    # Aggregate the total generation of non renewable and renewable energy in the LES
     for asset in dict_values[ENERGY_PRODUCTION]:
         if RENEWABLE_ASSET_BOOL in dict_values[ENERGY_PRODUCTION][asset]:
             sector = dict_values[ENERGY_PRODUCTION][asset][ENERGY_VECTOR]
@@ -305,6 +310,7 @@ def add_total_renewable_and_non_renewable_energy_origin(dict_values):
         }
     )
 
+    # Aggregate the total use of non renewable and renewable energy at DSO level
     for dso in dict_values[ENERGY_PROVIDERS]:
         sector = dict_values[ENERGY_PROVIDERS][dso][ENERGY_VECTOR]
 
@@ -348,26 +354,26 @@ def add_renewable_share_of_local_generation(dict_values):
     """Determination of renewable share of local energy production
 
         Parameters
-        ----------
-        dict_values :
-            dict with all project information and results, after applying add_total_renewable_and_non_renewable_energy_origin
-        sector :
-            Sector for which renewable share is being calculated
+    ----------
+    dict_values :
+        dict with all project information and results, after applying add_total_renewable_and_non_renewable_energy_origin
+    sector :
+        Sector for which renewable share is being calculated
 
-        Returns
-        -------
-        type
-            updated dict_values with renewable share of each sector as well as the system-wide KPI
+    Returns
+    -------
+    type
+        updated dict_values with renewable share of each sector as well as the system-wide KPI
 
-        Notes
-        -----
-        Updates the KPI with RENEWABLE_SHARE_OF_LOCAL_GENERATION for each sector as well as system-wide KPI.
+    Notes
+    -----
+    Updates the KPI with RENEWABLE_SHARE_OF_LOCAL_GENERATION for each sector as well as system-wide KPI.
 
-        Tested with
-        * test_renewable_share_of_local_generation_one_sector()
-        * test_renewable_share_of_local_generation_two_sectors()
-        * TestTechnicalKPI.renewable_factor_and_renewable_share_of_local_generation()
-        """
+    Tested with
+    * test_renewable_share_of_local_generation_one_sector()
+    * test_renewable_share_of_local_generation_two_sectors()
+    * TestTechnicalKPI.renewable_factor_and_renewable_share_of_local_generation()
+    """
 
     dict_renewable_share = {}
     for sector in dict_values[PROJECT_DATA][LES_ENERGY_VECTOR_S]:
@@ -402,7 +408,6 @@ def add_renewable_share_of_local_generation(dict_values):
             )
         }
     )
-    return
 
 
 def add_renewable_factor(dict_values):
@@ -458,7 +463,7 @@ def add_renewable_factor(dict_values):
 
 
 def equation_renewable_share(total_res, total_non_res):
-    """Calculates the renewable share
+    r"""Calculates the renewable share
 
     Parameters
     ----------
@@ -481,8 +486,7 @@ def equation_renewable_share(total_res, total_non_res):
     Equation:
 
     .. math::
-            RES = \frac{total_res}{total_non_res + total_res}
-
+        RES = \frac{total_res}{total_non_res + total_res}
 
     The renewable share is relative to generation, but not consumption of energy, the renewable share can not be larger 1.
     If there is no generation or consumption from a DSO within an energyVector and supply is solely reached by energy conversion from another vector, the renewable share is defined to be zero.
@@ -491,13 +495,14 @@ def equation_renewable_share(total_res, total_non_res):
     * renewable share < 1 - part of the energy in the system is of renewable origin
     * renewable share = 0 - no energy is of renewable origin
 
-
     Tested with:
+
     - test_renewable_share_equation_no_generation()
     - test_renewable_share_equation_below_1()
     - test_renewable_share_equation_is_0()
     - test_renewable_share_equation_is_1()
     """
+
     if total_res + total_non_res > 0:
         renewable_share = total_res / (total_non_res + total_res)
     else:
@@ -525,13 +530,16 @@ def add_degree_of_autonomy(dict_values):
     - test_add_degree_of_autonomy()
     """
 
-    total_generation = dict_values[KPI][KPI_SCALARS_DICT][TOTAL_GENERATION_IN_LES]
-
+    total_consumption_from_energy_provider = dict_values[KPI][KPI_SCALARS_DICT][
+        TOTAL_CONSUMPTION_FROM_PROVIDERS + SUFFIX_ELECTRICITY_EQUIVALENT
+    ]
     total_demand = dict_values[KPI][KPI_SCALARS_DICT][
         TOTAL_DEMAND + SUFFIX_ELECTRICITY_EQUIVALENT
     ]
 
-    degree_of_autonomy = equation_degree_of_autonomy(total_generation, total_demand)
+    degree_of_autonomy = equation_degree_of_autonomy(
+        total_consumption_from_energy_provider, total_demand
+    )
 
     dict_values[KPI][KPI_SCALARS_DICT].update({DEGREE_OF_AUTONOMY: degree_of_autonomy})
 
@@ -540,20 +548,18 @@ def add_degree_of_autonomy(dict_values):
     )
     logging.info(f"Calculated the {DEGREE_OF_AUTONOMY} of the LES.")
 
-    return
 
-
-def equation_degree_of_autonomy(total_generation, total_demand):
-    """
+def equation_degree_of_autonomy(total_consumption_from_energy_provider, total_demand):
+    r"""
     Calculates the degree of autonomy (DA).
 
-    The degree of autonomy describes the relation of the total locally
-    generated energy to the total demand of the system.
+    The degree of autonomy describes the relation of how much demand is supplied by local generation (as opposed to
+    grid conumption) compared to the total demand of the system.
 
     Parameters
     ----------
-    total_generation: float
-        total internal generation of energy
+    total_consumption_from_energy_provider: float
+        total energy consumption from providers
 
     total_demand: float
         total demand
@@ -564,22 +570,117 @@ def equation_degree_of_autonomy(total_generation, total_demand):
         degree of autonomy
 
     .. math::
-        DA &=\frac{\sum_{i} {E_{generation} (i) \cdot w_i}}{\sum_i {E_{demand} (i) \cdot w_i}}
+        DA &=\frac{\sum_i {E_{demand} (i) \cdot w_i} - \sum_{i} {E_{consumption,provider,j} (j) \cdot w_j}}{\sum_i {E_{demand} (i) \cdot w_i}}
 
-    A DA = 0 : System is totally dependent on the DSO,
-    DA = 1 : System is autonomous / a net-energy system
-    DA > 1 : a plus-energy system.
+    A DA = 0 : Demand is fully supplied by DSO consumption
+    DA = 1 : System is autonomous, ie. no DSO consumption is necessary
 
     Notice: As above, we apply a weighting based on Electricity Equivalent.
 
     Tested with
     - test_equation_degree_of_autonomy()
     """
-    degree_of_autonomy = total_generation / total_demand
+    degree_of_autonomy = (
+        total_demand - total_consumption_from_energy_provider
+    ) / total_demand
 
     return degree_of_autonomy
 
 
+def add_degree_of_net_zero_energy(dict_values):
+    """
+    Determines degree of net zero energy (NZE) and adds KPI to dict_values.
+
+    Parameters
+    ----------
+    dict_values: dict
+        dict with all project information and results,
+        after applying total_renewable_and_non_renewable_energy_origin and
+        total_demand_and_excess_each_sector
+
+    Returns
+    -------
+    None
+        updated dict_values with the degree of net zero energy
+
+    Notes
+    -----
+    As for other KPI, we apply a weighting based on Electricity Equivalent.
+
+    Tested with
+    - test_add_degree_of_net_zero_energy()
+    """
+
+    total_feedin = dict_values[KPI][KPI_SCALARS_DICT][
+        TOTAL_FEEDIN + SUFFIX_ELECTRICITY_EQUIVALENT
+    ]
+
+    total_consumption_from_energy_provider = dict_values[KPI][KPI_SCALARS_DICT][
+        TOTAL_CONSUMPTION_FROM_PROVIDERS + SUFFIX_ELECTRICITY_EQUIVALENT
+    ]
+    total_demand = dict_values[KPI][KPI_SCALARS_DICT][
+        TOTAL_DEMAND + SUFFIX_ELECTRICITY_EQUIVALENT
+    ]
+
+    degree_of_nze = equation_degree_of_net_zero_energy(
+        total_feedin, total_consumption_from_energy_provider, total_demand
+    )
+
+    dict_values[KPI][KPI_SCALARS_DICT].update({DEGREE_OF_NZE: degree_of_nze})
+
+    logging.debug(f"Calculated the {DEGREE_OF_NZE}: {round(degree_of_nze, 2)}")
+    logging.info(f"Calculated the {DEGREE_OF_NZE} of the LES.")
+
+
+def equation_degree_of_net_zero_energy(
+    total_feedin, total_grid_consumption, total_demand
+):
+    r"""
+    Calculates the degree of net zero energy (NZE).
+
+    In NZE systems import and export of energy is allowed while the balance over one
+    year should be zero, thus the degree of net zero energy would be 1. The
+    Degree of net zero energy indicates how close the system gets to the NZE ideal.
+    If more energy is exported than imported it is plus-energy system (degree of NZE > 1).
+
+    Parameters
+    ----------
+    total_feedin: float
+        total grid feed-in in electricity equivalents
+
+    total_grid_consumption: float
+        total consumption from energy provider in electricity equivalents
+    total_demand: float
+        total demand in electricity equivalents
+
+    Returns
+    -------
+    float
+        degree of net zero energy
+
+    Notes
+    -----
+
+    .. math::
+        Degree of NZE &= 1 + \frac{(\sum_{i} {E_{grid feedin}(i)} \cdot w_i - E_{grid consumption} (i) \cdot w_i)}{\sum_i {E_{demand, i} \cdot w_i}}
+
+    Degree of NZE = 1 : System is a net zero energy system, as E_feedin = E_grid_consumption
+    Degree of NZE > 1 : system is a plus-energy system, as E_feedin > E_grid_consumption
+    Degree of NZE < 1 : system does not reach net zero balance. The degree indicates by how much it fails to do so.
+    Degree of NZE = 0 : system has no internal production, as E_dem = E_grid_consumption.
+
+    Tested with
+    - test_equation_degree_of_net_zero_energy()
+    - test_equation_degree_of_net_zero_energy_is_zero()
+    - test_equation_degree_of_net_zero_energy_is_one()
+    - test_equation_degree_of_net_zero_energy_greater_one()
+
+    """
+    degree_of_nze = 1 + (total_feedin - total_grid_consumption) / total_demand
+
+    return degree_of_nze
+
+
 def add_degree_of_sector_coupling(dict_values):
     r"""
     Determines the aggregated flows in between the sectors and the Degree of Sector Coupling.
@@ -600,7 +701,7 @@ def add_degree_of_sector_coupling(dict_values):
         with i are conversion assets
 
     """
-    # todo actually only flows that transform an energy carrier from oone energy vector to the next should be added
+    # todo actually only flows that transform an energy carrier from one energy vector to the next should be added
     # maybe energyBusses helps?
     total_flow_of_energy_conversion_equivalent = 0
     for asset in dict_values[ENERGY_CONVERSION]:
@@ -635,7 +736,7 @@ def add_degree_of_sector_coupling(dict_values):
 def equation_degree_of_sector_coupling(
     total_flow_of_energy_conversion_equivalent, total_demand_equivalent
 ):
-    """Calculates degree of sector coupling.
+    r"""Calculates degree of sector coupling.
 
     Parameters
     ----------
@@ -651,7 +752,7 @@ def equation_degree_of_sector_coupling(
         Degree of sector coupling based on conversion flows and energy demands in electricity equivalent.
 
     .. math::
-       DSC=\frac{\sum_{i,j}{E_{conversion} (i,j)⋅w_i}}{\sum_i {E_{demand} (i)⋅w_i}}
+       DSC=\frac{\sum_{i,j}{E_{conversion} (i,j) \cdot w_i}}{\sum_i {E_{demand} (i) \cdot w_i}}
 
         with i,j \epsilon [Electricity,H2…]
 
@@ -662,7 +763,7 @@ def equation_degree_of_sector_coupling(
     return degree_of_sector_coupling
 
 
-def add_total_feedin_electricity_equivaluent(dict_values):
+def add_total_feedin_electricity_equivalent(dict_values):
     """
     Determines the total grid feed-in with weighting of electricity equivalent.
 
@@ -677,21 +778,19 @@ def add_total_feedin_electricity_equivaluent(dict_values):
         updated dict_values with KPI : total feedin
 
     Tested with
-    - test_add_total_feedin_electricity_equivaluent()
+    - test_add_total_feedin_electricity_equivalent()
     """
 
     total_feedin_dict = {}
     # Get source connected to the specific DSO in question
     for dso in dict_values[ENERGY_PROVIDERS]:
         # load total flow into the dso sink
-        consumption_asset = str(dso + DSO_FEEDIN + AUTO_SINK)
-        energy_carrier = dict_values[ENERGY_CONSUMPTION][consumption_asset][
-            ENERGY_VECTOR
-        ]
+        feedin_sink = str(dso + DSO_FEEDIN)
+        energy_carrier = dict_values[ENERGY_CONSUMPTION][feedin_sink][ENERGY_VECTOR]
         total_feedin_dict.update({energy_carrier: {}})
         total_feedin_dict.update(
             {
-                energy_carrier: dict_values[ENERGY_CONSUMPTION][consumption_asset][
+                energy_carrier: dict_values[ENERGY_CONSUMPTION][feedin_sink][
                     TOTAL_FLOW
                 ][VALUE]
             }
@@ -703,6 +802,52 @@ def add_total_feedin_electricity_equivaluent(dict_values):
     )
 
 
+def add_total_consumption_from_provider_electricity_equivalent(dict_values):
+    """
+    Determines the total consumption from energy providers with weighting of electricity equivalent.
+
+    Parameters
+    ----------
+    dict_values: dict
+        dict with all project information and results
+
+    Returns
+    -------
+    None
+        updated dict_values with KPI :
+        - TOTAL_CONSUMPTION_FROM_PROVIDERS + electricity,
+        - TOTAL_CONSUMPTION_FROM_PROVIDERS + electricity + SUFFIX_ELECTRICITY_EQUIVALENT
+        - TOTAL_CONSUMPTION_FROM_PROVIDERS + SUFFIX_ELECTRICITY_EQUIVALENT
+
+    Notes
+    -----
+    Tested with:
+    - E3.test_add_total_consumption_from_provider_electricity_equivalent()
+    """
+
+    total_consumption_dict = {}
+    # Get source connected to the specific DSO in question
+    for dso in dict_values[ENERGY_PROVIDERS]:
+        # load total flow into the dso sink
+        consumption_source = str(dso + DSO_CONSUMPTION)
+        energy_carrier = dict_values[ENERGY_PRODUCTION][consumption_source][
+            ENERGY_VECTOR
+        ]
+        total_consumption_dict.update({energy_carrier: {}})
+        total_consumption_dict.update(
+            {
+                energy_carrier: dict_values[ENERGY_PRODUCTION][consumption_source][
+                    TOTAL_FLOW
+                ][VALUE]
+            }
+        )
+
+    # Append total feedin in electricity equivalent to kpi
+    calculate_electricity_equivalent_for_a_set_of_aggregated_values(
+        dict_values, total_consumption_dict, kpi_name=TOTAL_CONSUMPTION_FROM_PROVIDERS
+    )
+
+
 def add_onsite_energy_fraction(dict_values):
     """
     Determines onsite energy fraction (OEF), i.e. self-consumption, and adds KPI to dict_values
@@ -742,35 +887,32 @@ def add_onsite_energy_fraction(dict_values):
     )
     logging.info(f"Calculated the {ONSITE_ENERGY_FRACTION} of the LES.")
 
-    return
-
 
 def equation_onsite_energy_fraction(total_generation, total_feedin):
-    """
+    r"""
     Calculates onsite energy fraction (OEF), i.e. self-consumption.
 
     OEF describes the fraction of all locally generated energy that is consumed
     by the system itself.
 
-        Parameters
-        ----------
-        total_generation: float
-            Energy equivalent of total generation flows
-        total_feedin: float
-            Total feed into the grid
+    Parameters
+    ----------
+    total_generation: float
+        Energy equivalent of total generation flows
+    total_feedin: float
+        Total feed into the grid
 
-        Returns
-        -------
-            float
-                Onsite energy fraction.
+    Returns
+    -------
+    float
+        Onsite energy fraction.
 
-        .. math::
-                OEF &=\frac{\sum_{i} {E_{generation} (i) \cdot w_i} - E_{gridfeedin}(i) \cdot w_i}{\sum_{i} {E_{generation} (i) \cdot w_i}}
+    .. math::
+            OEF &=\frac{\sum_{i} {E_{generation} (i) \cdot w_i} - E_{gridfeedin}(i) \cdot w_i}{\sum_{i} {E_{generation} (i) \cdot w_i}}
+            &OEF \epsilon \text{[0,1]}
 
-                &OEF \epsilon \text{[0,1]}
-
-        Tested with
-        - test_equation_onsite_energy_fraction()
+    Tested with
+    - test_equation_onsite_energy_fraction()
     """
 
     if total_generation != 0:
@@ -833,55 +975,140 @@ def add_onsite_energy_matching(dict_values):
     )
     logging.info(f"Calculated the {ONSITE_ENERGY_MATCHING} of the LES.")
 
-    return
-
 
 def equation_onsite_energy_matching(
     total_generation, total_feedin, total_excess, total_demand
 ):
-    """
+    r"""
     Calculates onsite energy matching (OEM), i.e. self-sufficiency.
 
     OEM describes the fraction of the total demand that can be
     covered by the locally generated energy.
 
-        Parameters
-        ----------
-        total_generation: float
-            Energy equivalent of total conversion flows
-        total_feedin: float
-            Total feed into the grid
-        total_excess: float
-            Total Excess energy
-        total_demand: float
-            Total demand
+    Parameters
+    ----------
+    total_generation: float
+        Energy equivalent of total conversion flows
+    total_feedin: float
+        Total feed into the grid
+    total_excess: float
+        Total Excess energy
+    total_demand: float
+        Total demand
 
-        Returns
-        -------
-        Onsite energy matching.
+    Returns
+    -------
+    Onsite energy matching.
 
-        .. math::
-                OEM &=\frac{\sum_{i} {E_{generation} (i) \cdot w_i} - E_{gridfeedin}(i) \cdot w_i - E_{excess}(i) \cdot w_i}{\sum_i {E_{demand} (i) \cdot w_i}}
+    .. math::
+            OEM &=\frac{\sum_{i} {E_{generation} (i) \cdot w_i} - E_{gridfeedin}(i) \cdot w_i - E_{excess}(i) \cdot w_i}{\sum_i {E_{demand} (i) \cdot w_i}}
 
-                &OEM \epsilon \text{[0,1]}
+            &OEM \epsilon \text{[0,1]}
 
-        Tested with
-        - test_equation_onsite_energy_matching()
-        """
+    Tested with
+    - test_equation_onsite_energy_matching()
+    """
     onsite_energy_matching = (
         total_generation - total_feedin - total_excess
     ) / total_demand
     return onsite_energy_matching
 
 
-def equation_co2_emissions(dict_values):
-    co2_emissions = 0
-    for asset in dict_values[ENERGY_PRODUCTION]:
-        co2_emissions += (
-            dict_values[ENERGY_PRODUCTION][asset]["total_aggregated_flow"][VALUE]
-            * dict_values[ENERGY_PRODUCTION][asset]["emissionFactor"][VALUE]
-        )
-    return co2_emissions
+def calculate_emissions_from_flow(dict_asset):
+    r"""
+    Calculates the total emissions of the asset in 'dict_asset' in kg per year.
+
+    Parameters
+    ----------
+    dict_asset : dict
+        Contains information about the asset.
+
+    Notes
+    -----
+    Tested with:
+    - E3.test_calculate_emissions_from_flow()
+    - E3.test_calculate_emissions_from_flow_zero_emissions
+
+    Returns
+    -------
+    None
+        Updated `dict_asset` with TOTAL_EMISSIONS of the asset in kgCO2eq/a (UNIT_EMISSIONS).
+
+    """
+    emissions = dict_asset[TOTAL_FLOW][VALUE] * dict_asset[EMISSION_FACTOR][VALUE]
+    dict_asset.update({TOTAL_EMISSIONS: {VALUE: emissions, UNIT: UNIT_EMISSIONS}})
+
+
+def add_total_emissions(dict_values):
+    r"""
+    Calculates the total emission of the energy system in kgCO2eq/a and adds KPI to `dict_values`.
+
+    Parameters
+    ----------
+    dict_values: dict
+        All simulation inputs and results
+
+    Returns
+    -------
+    None
+        Updated `dict_values` with TOTAL_EMISSIONS of the energy system in kgCO2eq/a
+        (UNIT_EMISSIONS).
+
+    Notes
+    -----
+
+    Tested with:
+    - E3.test_add_total_emissions()
+
+    """
+    # sum up emissions of all assets [kgCO2eq/a]
+    emissions = dict_values[KPI][KPI_SCALAR_MATRIX][TOTAL_EMISSIONS].sum()  # data frame
+    dict_values[KPI][KPI_SCALARS_DICT].update({TOTAL_EMISSIONS: emissions})
+    logging.debug(
+        f"Calculated the {TOTAL_EMISSIONS}: {round(emissions, 2)} {UNIT_EMISSIONS}."
+    )
+    logging.info(f"Calculated the {TOTAL_EMISSIONS} ({UNIT_EMISSIONS}) of the LES.")
+
+
+def add_specific_emissions_per_electricity_equivalent(dict_values):
+    r"""
+    Calculates the specific emissions of the energy system per kWheleq and adds KPI to `dict_values`.
+
+    Parameters
+    ----------
+    dict_values: dict
+        All simulation inputs and results including TOTAL_EMISSIONS calculated in
+        `E3.calculate_emissions_from_flow`.
+
+    Notes
+    -----
+    This funtion is run after `E3.calculate_emissions_from_flow`.
+
+    Tested with:
+    - E3.test_add_specific_emissions_per_electricity_equivalent()
+
+    Returns
+    -------
+    None
+        Updated `dict_values` with SPECIFIC_EMISSIONS_ELEQ in kgCO2eq/kWheleq (UNIT_SPECIFIC_EMISSIONS).
+
+    """
+    # emissions per kWheleq
+    emissions_kWheleq = (
+        dict_values[KPI][KPI_SCALARS_DICT][TOTAL_EMISSIONS]
+        / dict_values[KPI][KPI_SCALARS_DICT][
+            TOTAL_DEMAND + SUFFIX_ELECTRICITY_EQUIVALENT
+        ]
+    )
+    dict_values[KPI][KPI_SCALARS_DICT].update(
+        {SPECIFIC_EMISSIONS_ELEQ: emissions_kWheleq}
+    )
+    logging.debug(
+        f"Calculated the {SPECIFIC_EMISSIONS_ELEQ}: {round(emissions_kWheleq, 2)} {UNIT_SPECIFIC_EMISSIONS}."
+    )
+    logging.info(
+        f"Calculated the {SPECIFIC_EMISSIONS_ELEQ} ({UNIT_SPECIFIC_EMISSIONS}) of the LES."
+    )
 
 
 def add_levelized_cost_of_energy_carriers(dict_values):
@@ -895,7 +1122,14 @@ def add_levelized_cost_of_energy_carriers(dict_values):
 
     Returns
     -------
-    Updates KPI_SCALAR_DICT
+    Updated KPI_SCALAR_DICT: Add `ATTRIBUTED_COSTS` and `LCOeleq` for each energy carrier as well as `LCOeleq` for overall energy system
+
+    Notes
+    -----
+
+    Tested with:
+        - test_E3_indicator_calculation.test_add_levelized_cost_of_energy_carriers_one_sector()
+        - test_E3_indicator_calculation.test_add_levelized_cost_of_energy_carriers_two_sectors()
     """
     # Abbreviate costs accessed
     NPC = dict_values[KPI][KPI_SCALARS_DICT][COST_TOTAL]
@@ -909,10 +1143,10 @@ def add_levelized_cost_of_energy_carriers(dict_values):
     for energy_carrier in dict_values[PROJECT_DATA][LES_ENERGY_VECTOR_S]:
         # Get energy carrier specific values
         energy_carrier_label = TOTAL_DEMAND + energy_carrier
-        total_flow_energy_carrier_eleq = dict_values[KPI][KPI_SCALARS_DICT][
+        total_flow_energy_carrier = dict_values[KPI][KPI_SCALARS_DICT][
             energy_carrier_label
         ]
-        total_flow_energy_carrier = dict_values[KPI][KPI_SCALARS_DICT][
+        total_flow_energy_carrier_eleq = dict_values[KPI][KPI_SCALARS_DICT][
             energy_carrier_label + SUFFIX_ELECTRICITY_EQUIVALENT
         ]
         # Calculate LCOE of energy carrier
@@ -993,11 +1227,11 @@ def equation_levelized_cost_of_energy_carrier(
 
     The costs attributed to an energy carrier are calculated from the ratio of electricity equivalent of the energy carrier demand in focus to the electricity equivalent of the total demand:
 
-    .. math: attributed costs = NPC \cdot \frac{Total electricity equivalent of energy carrier demand}{Total electricity equivalent of demand}
+    .. math:: attributed costs = NPC \cdot \frac{Total electricity equivalent of energy carrier demand}{Total electricity equivalent of demand}
 
     The LCOE sets these attributed costs in relation to the energy carrier demand (in its original unit):
 
-    .. math: LCOE energy carrier = \frac{attributed costs \cdot CRF}{total energy carrier demand}
+    .. math:: LCOE energy carrier = \frac{attributed costs \cdot CRF}{total energy carrier demand}
 
     Tested with:
     - test_equation_levelized_cost_of_energy_carrier_total_demand_electricity_equivalent_larger_0_total_flow_energy_carrier_larger_0()
@@ -1059,4 +1293,3 @@ def weighting_for_sector_coupled_kpi(dict_values, kpi_name):
     )
     # Describes system wide total of the energy equivalent of the kpi
     dict_values[KPI][KPI_SCALARS_DICT].update({kpi_name: total_energy_equivalent})
-    return
